/* ZGV v2.0 - (c) 1993,1994 Russell Marks for improbabledesigns.
 * See README for license details.
 *
 * rcfile.h - protos for rcfile.c
 */

extern struct zgv_config cfg;

/* rcfile.c */
extern int getconfig(void);
extern int saveconfig(void);
extern int modematch(int,int,int);
extern int parsecommandline(int argc,char **argv);
extern int usage_help();
